![zug-zug](https://github.com/user-attachments/assets/7c60873d-5c35-4cd3-985e-2b61e690c6f9)

# Workcraft Peon

## A simple, lightweight, worker library in Python and Go

This is the worker half of the Workcraft project.

Go read the docs!

Todo: Add docs
